<?php
//  if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly 

function seoforge_create_blog_post($title) {
    // Supprimer la numérotation avant le titre (par exemple "1. ", "2. ")
    $clean_title = preg_replace('/^\d+\.\s*/', '', $title);

    // Supprimer les guillemets simples ou doubles s'ils sont au début et à la fin du titre
    $clean_title = preg_replace('/^["\'](.*)["\']$/', '$1', $clean_title);
    // Supprimer les backslashes échappés
    $clean_title = esc_html(stripslashes($clean_title));

    $custom_prompt = get_option('seoforge_custom_prompt');
    // Utiliser le titre nettoyé pour générer un prompt pour GPT
    $prompt = "Write a complete blog article on the following topic: " . $clean_title . " " . $custom_prompt;

    // Appel à l'API ChatGPT pour générer le contenu de l'article
    $content = seoforge_send_prompt_to_chatgpt($prompt);
    
    if (!$content) {
        $content = 'Error generating content. Please try again.'; // Gérer les erreurs
    }
    if (preg_match('/<article>(.*?)<\/article>/s', $content, $matches)) {
        $content = $matches[1]; // Le contenu capturé se trouve dans $matches[1]
    }
    $content = str_replace("```html", "", $content);
    $content = str_replace("```", "", $content);
    $content = str_replace("<p><br /><br /><br /><br /><br /></p>", "", $content);
    // Créer un nouvel article de blog avec le titre et le contenu généré
    $new_post = array(
        'post_title'    => wp_strip_all_tags($clean_title),
        'post_content'  => $content,
        'post_status'   => 'draft',  // Enregistrer comme brouillon
        'post_author'   => get_current_user_id(),
        'post_category' => array(1)  // Catégorie par défaut (peut être personnalisée)
    );

    // Insérer l'article et obtenir l'ID de l'article
    $post_id = wp_insert_post($new_post);

    // // Générer une image basée sur le titre et l'ajouter en tant qu'image à la une
    if ($post_id && get_option('seoforge_image_generation_enabled') ) {
        seoforge_generate_featured_image( $post_id, $clean_title );
    }
}

?>