<?php
/**
 * Plugin Name: SeoForge
 * Plugin URI: https://seoforge.io
 * Description: A WordPress plugin that integrates with OpenAI’s GPT for content generation.
 * Version: 1.2
 * Author: Weclix
 * Author URI: https://weclix.online
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: seoforge
 */

if (!defined('ABSPATH')) {
    exit; // Security: block direct access
}



// Include necessary files
require_once plugin_dir_path(__FILE__) . 'prompt.php';
require_once plugin_dir_path(__FILE__) . 'posts.php';
require_once plugin_dir_path(__FILE__) . 'menu.php';
require_once plugin_dir_path(__FILE__) . 'pages.php';



function seoforge_add_settings_link($links) {
    if (is_plugin_active(plugin_basename(__FILE__))) {
        // URL for the "Settings" page
        $settings_link = '<a href="' . admin_url('admin.php?page=seoforge_settings') . '">Settings</a>';

        // Add the link to the list of plugin action links
        array_push($links, $settings_link);
    }

    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'seoforge_add_settings_link');
function seoforge_add_upgrade_link($links) {
    // URL du lien "Upgrade to Pro"
    $upgrade_link = '<a href="https://seoforge.io/pro" target="_blank" style="color: #1da867; font-weight: bold;">Upgrade to Pro</a>';

    // Ajouter le lien à la liste des actions du plugin
    array_push($links, $upgrade_link);

    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'seoforge_add_upgrade_link');
// Data client function to connect to the API
function dataclient(){
    // Define the base URL for the Symfony API
    $url = 'https://api.seoforge.io/blogpost/getclient';

    // Build the query URL with the 'token' parameter
    $query_url = add_query_arg(array('token' => get_option('seoforge_token_id')), $url);

    // Make a GET request to the Symfony API
    $response = wp_remote_get($query_url, array(
        'timeout' => 1000, // Adjust the timeout as needed
        'httpversion' => '1.1',
        'blocking' => true
    ));

    // Check if the request failed
    if (is_wp_error($response)) {
        return 'Error connecting to server: ' . $response->get_error_message();
    }

    // Extract and decode the body of the response
    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    return $data;
}
// Function to run after plugin activation is detected
function seoforge_run_on_activation() {
    // Check if the plugin was just activated
    if (is_admin() && get_option('seoforge_activated')) {
        // Delete the 'seoforge_activated' option
        delete_option('seoforge_activated');

        // Generate a unique 32-character token
        $token = wp_generate_password(32, false);
        add_option('seoforge_token_id', $token);
        update_option('seoforge_token_id', $token);
        $website_url = isset($_SERVER['HTTP_HOST']) ? sanitize_text_field(wp_unslash($_SERVER['HTTP_HOST'])) : '';

     
        $url = 'https://api.seoforge.io/blogpost/save-client?token='.$token.'&website_url='.$website_url; 
        // Faire une requête POST avec les paramètres dans le body
        $response = wp_remote_post($url, array(
            'method' => 'POST',
            'timeout' => 1000,
            'httpversion' => '1.1',
            'blocking' => true,
            'headers' => array(
                'Content-Type' => 'application/json',
            ),
           
        ));
    

        // Display an admin notice to indicate activation was successful
        add_action('admin_notices', function() use ($token) {
            echo '<div class="notice notice-success is-dismissible"><p>SEOForge has been activated. Token generated: ' . esc_html($token) . '</p></div>';
        });
    }
}
add_action('admin_init', 'seoforge_run_on_activation');

// Function to set an activation flag during plugin activation
function seoforge_activate() {
    // Set an option to indicate the plugin was just activated
    add_option('seoforge_activated', true);
}
register_activation_hook(__FILE__, 'seoforge_activate'); 
// // Register the uninstall hook
// register_uninstall_hook(__FILE__, 'uninstall_seoforge');

// // Uninstall function to clean up options
// function uninstall_seoforge() {
//     // Delete regular options
//     delete_option('seoforge_token_id');

//     // Delete network-wide options for multisite installations
//     if (is_multisite()) {
//         delete_site_option('seoforge_token_id');
//     }
// }

