<?php
// Prevent direct access
if (!defined('ABSPATH')) {
    exit;
}

// Display any admin notices
if (isset($_GET['notice'])) {
    $notice = sanitize_text_field(wp_unslash($_GET['notice']));
    echo '<div class="notice notice-success is-dismissible"><p>' . esc_html($notice) . '</p></div>';
}

// Handle form submissions securely
if (isset($_POST['submit_prompt']) && isset($_POST['submit_prompt_nonce'])) {
    $submit_prompt_nonce = sanitize_text_field(wp_unslash($_POST['submit_prompt_nonce']));

    if (wp_verify_nonce($submit_prompt_nonce, 'submit_prompt_action')) {
        $prompt = isset($_POST['prompt']) ? sanitize_text_field(wp_unslash($_POST['prompt'])) : '';
        $response = seoforge_send_prompt_to_chatgpt($prompt);

        if ($response) {
            update_option('seoforge_last_prompt', $prompt);
            update_option('seoforge_last_response', $response);
        } else {
            wp_die('Failed to get a response from ChatGPT.');
        }
    } else {
        wp_die('Nonce verification failed.');
    }
}

if (isset($_POST['reset_conversation']) && isset($_POST['reset_conversation_nonce'])) {
    $reset_conversation_nonce = sanitize_text_field(wp_unslash($_POST['reset_conversation_nonce']));

    if (wp_verify_nonce($reset_conversation_nonce, 'reset_conversation_action')) {
        delete_option('seoforge_conversation_history');
        echo '<div class="notice notice-success is-dismissible"><p>Conversation history cleared successfully.</p></div>';
    } else {
        wp_die('Nonce verification failed.');
    }
}
?>

<div class="seoforge-chatgpt-wrapper">
    <form method="post" class="seoforge-prompt-form">
        <?php wp_nonce_field('submit_prompt_action', 'submit_prompt_nonce'); ?>
        <label for="prompt">Enter your prompt:</label><br>
        <textarea id="prompt" name="prompt" rows="5" cols="60"><?php echo esc_textarea(get_option('seoforge_last_prompt', 'Find the top 50 topics on [YOUR TOPIC], including current events and new trends, and generate blog post titles. Present them as a list, writing only the title and removing quotation marks from the list. Write the article titles as an expert in [YOUR FIELD].')); ?></textarea><br><br>
        <input type="submit" name="submit_prompt" value="Send Prompt" class="button button-primary">
    </form>

    <form method="post" class="seoforge-reset-form" style="margin-top: 20px;">
        <?php wp_nonce_field('reset_conversation_action', 'reset_conversation_nonce'); ?>
        <input type="submit" name="reset_conversation" value="Clear Conversation History" class="button button-secondary">
    </form>

    <?php
    $saved_response = get_option('seoforge_last_response', '');
    if (!empty($saved_response)) {
        echo '<h2>Blog</h2>';
        $lines = explode("\n", $saved_response);
        echo '<ul class="seoforge-response-list">';
        foreach ($lines as $index => $line) {
            if (!empty(trim($line))) {
                echo '<li id="article-' . esc_attr($index) . '">' . esc_html($line);
                echo '<form method="post" class="create-article-form" data-index="' . esc_attr($index) . '">';
                echo '<input type="hidden" name="blog_post_title" value="' . esc_attr($line) . '">';
                echo '<input type="submit" name="create_blog_post" value="Create Blog Post" class="button button-primary">';
                echo '<span id="loading-' . esc_attr($index) . '" class="seoforge-loading" style="display:none;">Creating...</span>';
                echo '</form></li>';
            }
        }
        echo '</ul>';
    }
    ?>
</div>